"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("dotenv/config");
const express_1 = __importDefault(require("express"));
const promises_1 = __importDefault(require("fs/promises"));
const body_parser_1 = __importDefault(require("body-parser"));
const Handlebars = __importStar(require("handlebars"));
const log_1 = require("./log");
const files_1 = require("./files");
const log = (0, log_1.createLog)('fm');
const app = (0, express_1.default)();
let fd;
let index;
let port;
let sequences;
let videos;
let width;
let height;
log.info('Starting filmout_manager...');
app.use(body_parser_1.default.json());
app.use(body_parser_1.default.urlencoded({ extended: true }));
async function createTemplate(filePath) {
    let tmpl;
    try {
        tmpl = await promises_1.default.readFile(filePath, 'utf8');
    }
    catch (err) {
        log.error(err);
        return null;
    }
    return Handlebars.compile(tmpl);
}
async function settings() {
    let sequencesExists = false;
    let videosExists = false;
    if (typeof process.env['FD'] === 'undefined') {
        log.error('Please include an FD value containing the path to your fd binary in .env');
        process.exit(1);
    }
    else {
        log.info(`FD=${process.env['FD']}`);
    }
    if (typeof process.env['WIDTH'] === 'undefined') {
        log.error('Please include a WIDTH value containing the width of the screen you are using in .env');
        process.exit(2);
    }
    else {
        width = parseInt(process.env['WIDTH']);
        log.info(`WIDTH=${width}`);
    }
    if (typeof process.env['HEIGHT'] === 'undefined') {
        log.error('Please include a HEIGHT value containing the height of the screen you are using in .env');
        process.exit(3);
    }
    else {
        height = parseInt(process.env['HEIGHT']);
        log.info(`HEIGHT=${height}`);
    }
    if (typeof process.env['FD_HOST'] === 'undefined') {
        log.error('Please include a FD_HOST value with the host that the fd socket server is hosted on in .env');
        process.exit(4);
    }
    else {
        log.info(`FD_HOST=${process.env['FD_HOST']}`);
    }
    if (typeof process.env['FD_PORT'] === 'undefined') {
        log.error('Please include a FD_PORT value with the port that the fd socket server is hosted on in .env');
        process.exit(5);
    }
    else {
        log.info(`FD_PORT=${process.env['FD_PORT']}`);
    }
    if (typeof process.env['PORT'] === 'undefined') {
        log.error('Please include a PORT value with the port that the HTTP web process is hosted on in .env');
        process.exit(6);
    }
    else {
        port = parseInt(process.env['PORT']);
        log.info(`PORT=${port}`);
    }
    if (typeof process.env['SEQUENCES'] === 'undefined') {
        log.error('Please include a SEQUENCES directory where the image sequences will be located in .env');
        process.exit(7);
    }
    else {
        sequences = process.env['SEQUENCES'];
        sequencesExists = await files_1.Files.exists(sequences);
        if (!sequencesExists) {
            log.error(`The SEQUENCES directory in .env, ${sequences}, does not exist`);
            process.exit(8);
        }
        log.info(`SEQUENCES=${sequences}`);
    }
    if (typeof process.env['VIDEOS'] === 'undefined') {
        log.error('Please include a VIDEOS directory where the videos will be located in .env');
        process.exit(7);
    }
    else {
        videos = process.env['VIDEOS'];
        videosExists = await files_1.Files.exists(videos);
        if (!sequencesExists) {
            log.error(`The VIDEOS directory in .env, ${videos}, does not exist`);
            process.exit(8);
        }
        log.info(`VIDEOS=${videos}`);
    }
}
app.get('/', async (req, res, next) => {
    const dirs = await files_1.Files.enumerateSequences(sequences);
    const html = index({ dirs, width, height });
    res.send(html);
});
async function main() {
    await settings();
    index = await createTemplate('./views/index.hbs');
    //fd = new FD(process.env['FD'], width, height,  process.env['FD_HOST'],  parseInt(process.env['FD_PORT'])); 
    app.listen(port, async () => {
        log.info(`filmout_manager HTTP server running on port ${port}`);
    });
}
main();
//# sourceMappingURL=index.js.map